Fetch player meta data from ESPNCricinfo and return a tibble with one line
per player. To identify the players, use their Cricinfo player IDs.
The simplest way to find this is to look up their Cricinfo Profile page. The number
at the end of the URL is the ID. For example, Meg Lanning's profile page is
http://www.espncricinfo.com/australia/content/player/329336.html,
so her ID is 329336.
Usage
fetch_player_meta(playerid)
Value
A tibble containing meta data on the selected players, with one row for
each player.
Arguments
playerid
A vector of player IDs as given in Cricinfo profiles. Integer or character.
Author
Hassan Rafique and Rob J Hyndman
See Also
It is usually simpler to just use the saved data set player_meta
which contains the meta data for all players on ESPNCricinfo as at 28 August 2023.
To find a player ID, use find_player_id().
Use fetch_player_data() to download playing statistics for a player.